@@ -1,11 +1,10 @@
 jomo1rancat <-
   function(Y_cat, Y_numcat, X=matrix(1,nrow(Y_cat),1), Z=matrix(1,nrow(Y_cat),1), clus, betap=matrix(0,ncol(X),((sum(Y_numcat)-length(Y_numcat)))), up=matrix(0,nrow(unique(clus)),ncol(Z)*((sum(Y_numcat)-length(Y_numcat)))), covp=diag(1,ncol(betap)), covu=diag(1,ncol(up)), Sp=diag(1,ncol(covp)), Sup=diag(1,ncol(covu)), nburn=100, nbetween=100, nimp=5, output=1, out.iter=10) {
-    Ycatsum1<-rep(0,ncol(Y_cat))
+    previous_levels<-list()
     for (i in 1:ncol(Y_cat)) {
-      if (min(as.numeric(Y_cat[!is.na(Y_cat[,i]),i]))==0) {
-        Y_cat[!is.na(Y_cat[,i]),i]<-factor(as.numeric(Y_cat[!is.na(Y_cat[,i]),i])+1)
-        Ycatsum1[i]<-1
-      }
+      Y_cat[,i]<-factor(Y_cat[,i])
+      previous_levels[[i]]<-levels(Y_cat[,i])
+      levels(Y_cat[,i])<-1:nlevels(Y_cat[,i])
     }
     for (i in 1:ncol(X)) {
       if (is.factor(X[,i])) X[,i]<-as.numeric(X[,i])
@@ -33,10 +32,10 @@ jomo1rancat <-
     colnamycat<-colnames(Y_cat)
     colnamx<-colnames(X)
     colnamz<-colnames(Z)
-    Y_cat<-as.matrix(Y_cat,nrow(Y_cat),ncol(Y_cat))
-    X<-as.matrix(X,nrow(X),ncol(X))
-    Z<-as.matrix(Z,nrow(Z),ncol(Z))
-    clus<-as.matrix(clus,nrow(clus),ncol(clus))
+    Y_cat<-data.matrix(Y_cat)
+    X<-data.matrix(X)
+    Z<-data.matrix(Z)
+    clus<-data.matrix(clus)
     Y=cbind(Y_cat)
     Yi=cbind(matrix(0,nrow(Y_cat),(sum(Y_numcat)-length(Y_numcat))))
     h=1
@@ -118,12 +117,8 @@ jomo1rancat <-
     }
     imp<-data.frame(imp)
     for (i in 1:ncol(Y)) {
-      if (Ycatsum1[i]==1) {
-        imp[,i]<-as.factor(imp[,i]-1)                  
-      }
-      else {
-        imp[,i]<-as.factor(imp[,i]) 
-      }
+      imp[,i]<-as.factor(imp[,i]) 
+      levels(imp[,i])<-previous_levels[[i]]
     }
     if (is.null(colnamycat)) colnamycat=paste("Ycat", 1:ncol(Y_cat), sep = "")
     if (is.null(colnamz)) colnamz=paste("Z", 1:ncol(Z), sep = "")
