@@ -25,10 +25,10 @@ jomo1rancon<- function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, be
   colnamy<-colnames(Y)
   colnamx<-colnames(X)
   colnamz<-colnames(Z)
-  Y<-as.matrix(Y,nrow(Y),ncol(Y))
-  X<-as.matrix(X,nrow(X),ncol(X))
-  Z<-as.matrix(Z,nrow(Z),ncol(Z))
-  clus<-as.matrix(clus,nrow(clus),ncol(clus))
+  Y<-data.matrix(Y)
+  X<-data.matrix(X)
+  Z<-data.matrix(Z)
+  clus<-data.matrix(clus)
   if (output!=1) out.iter=nburn+nbetween
   imp=matrix(0,nrow(Y)*(nimp+1),ncol(Y)+ncol(X)+ncol(Z)+3)
   imp[1:nrow(Y),1:ncol(Y)]=Y
